@@ -11,10 +11,21 @@ from tensorflow.keras.models import Model
 from tensorflow.keras.optimizers import Adam
 from tensorflow.keras.callbacks import TensorBoard, ModelCheckpoint, ReduceLROnPlateau, EarlyStopping
 
-from .model import preprocess_true_boxes, yolo_body, tiny_yolo_body, yolo_loss,yolo_efficientnetb3_body
-from .utils import get_random_data
+from .model import yolo_body, tiny_yolo_body, yolo_loss, \
+    yolo_efficientnetb3_body, yolo_efficientnetliteb4_body, yolo_efficientnetliteb1_body, yolo_efficientnetb0_body
+from .utils import get_random_data, preprocess_true_boxes, get_anchors, get_classes, data_generator_wrapper
 
 
+def create_datagenerator(train_annotation_path, val_annotation_path, batch_size, input_shape, anchors, num_classes):
+    with open(train_annotation_path, encoding="utf-8") as f:
+        train_lines = f.readlines()
+    with open(val_annotation_path, encoding="utf-8") as f:
+        val_lines = f.readlines()
+    train = data_generator_wrapper(train_lines, batch_size, input_shape, anchors, num_classes)
+    val = data_generator_wrapper(val_lines, batch_size, input_shape, anchors,
+                                 num_classes)
+    return train, val
+
 
 def _main(train_annotation_path, val_annotation_path, classes_path, anchors_path, weights_path):
     log_dir = './logs/000/'
@@ -88,22 +99,6 @@ def _main(train_annotation_path, val_annotation_path, classes_path, anchors_path
         model.save_weights('./model/yolov3_trained_weights_final.h5')
 
 
-def get_classes(classes_path):
-    '''loads the classes'''
-    with open(classes_path) as f:
-        class_names = f.readlines()
-    class_names = [c.strip() for c in class_names]
-    return class_names
-
-
-def get_anchors(anchors_path):
-    '''loads the anchors from a file'''
-    with open(anchors_path) as f:
-        anchors = f.readline()
-    anchors = [float(x) for x in anchors.split(',')]
-    return np.array(anchors).reshape(-1, 2)
-
-
 def create_model(input_shape, anchors, num_classes, load_pretrained=True, freeze_body=2,
                  weights_path='model_data/yolo_weights.h5'):
     '''create the training model'''
@@ -167,32 +162,6 @@ def create_tiny_model(input_shape, anchors, num_classes, load_pretrained=True, f
     return model
 
 
-def data_generator(annotation_lines, batch_size, input_shape, anchors, num_classes):
-    '''data generator for fit_generator'''
-    n = len(annotation_lines)
-    i = 0
-    while True:
-        image_data = []
-        box_data = []
-        for b in range(batch_size):
-            if i == 0:
-                np.random.shuffle(annotation_lines)
-            image, box = get_random_data(annotation_lines[i], input_shape, random=True)
-            image_data.append(image)
-            box_data.append(box)
-            i = (i + 1) % n
-        image_data = np.array(image_data)
-        box_data = np.array(box_data)
-        y_true = preprocess_true_boxes(box_data, input_shape, anchors, num_classes)
-        yield [image_data, *y_true], np.zeros(batch_size)
-
-
-def data_generator_wrapper(annotation_lines, batch_size, input_shape, anchors, num_classes):
-    n = len(annotation_lines)
-    if n == 0 or batch_size <= 0: return None
-    return data_generator(annotation_lines, batch_size, input_shape, anchors, num_classes)
-
-
 if __name__ == '__main__':
     image_input = Input(shape=(380, 380, 3))
-    model_body = yolo_efficientnet_body(image_input, 3, 16)
\ No newline at end of file
+    # model_body = yolo_efficientnet_body(image_input, 3, 16)
